@@ -1,9 +1,11 @@
-from pydantic import BaseModel
 from typing import Any
 from abc import ABC, abstractmethod
 
+from dataclasses import dataclass
 
-class SourceResponse(BaseModel):
+
+@dataclass
+class SourceResponse:
     exists: bool
     value: Any
 
@@ -12,3 +14,5 @@ class Source(ABC):
     @abstractmethod
     def get_value(self, key: str) -> SourceResponse:
         'Get the value in the source using the key'
+
+s = SourceResponse(**{"exists": True, "value": "1"})
\ No newline at end of file
